==> kapla-2.0.1.tgz: package/lib/helpers/autoLoad.js <==
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

/**
 * Load definitions from webpack context
 *
 * @export
 * @param {any} context webpack context
 * @param {object} options options
 * @returns {Array} definitions
 */
export function autoLoad(context) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {
    stripFolders: 1
  };
  return context.keys().map(function (key) {
    return getDefinition(context, key, options);
  }).filter(function (value) {
    return value;
  });
}
/**
 * Get the definition using slug
 *
 * @param {any} context webpack context
 * @param {String} key component filename/path
 * @param {object} options options
 * @returns {Object} definition
 */

function getDefinition(context, key, options) {
  var slug = getSlug(key, options.stripFolders);

  if (slug) {
    return buildDefinition(context(key), slug);
  }

  return false;
}
/**
 * Build definition
 *
 * @param {Function} module component constructor
 * @param {String} slug component name
 * @returns {Object} definition
 */


function buildDefinition(module, slug) {
  var ComponentConstructor = module.default;

  if (typeof ComponentConstructor === 'function') {
    return {
      slug: slug,
      ComponentConstructor: ComponentConstructor
    };
  }

  return false;
}
/**
 * Get slug from filename/path
 *
 * @param {String} key component filename/path
 * @param {Number} stripFolders strip folders from path (starts from "base")
 * @returns {String} component name
 */


function getSlug(key, stripFolders) {
  // [folder/[subfolders/]]MyComponentFileName.js
  var regex = /^(?:\.\/)?([A-Z]{1}[A-Za-z]+|[a-z/]+\/[A-Z]{1}[A-Za-z]+)(?:\.js?)$/;

  var _ref = key.match(regex) || [],
      _ref2 = _slicedToArray(_ref, 2),
      logicalName = _ref2[1];

  if (logicalName) {
    for (var i = 0; i < stripFolders; i++) {
      logicalName = logicalName.replace(/^([a-zA-Z]+\/)/, '');
    }

    return logicalName // Ex: 1. AbbAbb || 2. bb/bb/AbbAbb
    .replace(/([A-Z])/g, '-$1') // 1. -Abb-Abb || 2. bb/bb/-Abb-Abb
    .replace(/^-/, '') // 1. Abb-Abb
    .replace(/\/-/g, '/') // 2. bb/bb/Abb-Abb
    .replace(/\//g, '--') // 2. bb--bb--Abb-Abb
    .toLowerCase(); // 1. abb-abb || 2. bb--bb--abb-abb
  }

  return false;
}

==> kapla-2.1.4.tgz: package/lib/helpers/autoLoad.js <==
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) { return; } var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

/**
 * Load definitions from webpack context
 *
 * @export
 * @param {any} context webpack context
 * @param {object} options options
 * @returns {Array} definitions
 */
export function autoLoad(context) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {
    stripFolders: 1
  };
  return context.keys().map(function (key) {
    return getDefinition(context, key, options);
  }).filter(function (value) {
    return value;
  });
}
/**
 * Get the definition using slug
 *
 * @param {any} context webpack context
 * @param {String} key component filename/path
 * @param {object} options options
 * @returns {Object} definition
 */

function getDefinition(context, key, options) {
  var slug = getSlug(key, options.stripFolders);

  if (slug) {
    return buildDefinition(context(key), slug);
  }

  return false;
}
/**
 * Build definition
 *
 * @param {Function} module component constructor
 * @param {String} slug component name
 * @returns {Object} definition
 */


function buildDefinition(module, slug) {
  var ComponentConstructor = module.default;

  if (typeof ComponentConstructor === 'function') {
    return {
      slug: slug,
      ComponentConstructor: ComponentConstructor
    };
  }

  return false;
}
/**
 * Get slug from filename/path
 *
 * @param {String} key component filename/path
 * @param {Number} stripFolders strip folders from path (starts from "base")
 * @returns {String} component name
 */


function getSlug(key, stripFolders) {
  // [folder/[subfolders/]]MyComponentFileName.js
  var regex = /^(?:\.\/)?([A-Z]{1}[A-Za-z]+|[a-z-/]+\/[A-Z]{1}[A-Za-z]+)(?:\.js?)$/;

  var _ref = key.match(regex) || [],
      _ref2 = _slicedToArray(_ref, 2),
      logicalName = _ref2[1];

  if (logicalName) {
    for (var i = 0; i < stripFolders; i++) {
      logicalName = logicalName.replace(/^([a-zA-Z]+\/)/, '');
    }

    return logicalName // Ex: 1. AbbAbb || 2. bb/bb/AbbAbb
    .replace(/([A-Z])/g, '-$1') // 1. -Abb-Abb || 2. bb/bb/-Abb-Abb
    .replace(/^-/, '') // 1. Abb-Abb
    .replace(/\/-/g, '/') // 2. bb/bb/Abb-Abb
    .replace(/\//g, '--') // 2. bb--bb--Abb-Abb
    .toLowerCase(); // 1. abb-abb || 2. bb--bb--abb-abb
  }

  return false;
}
